#
# spec file for package python-translationstring
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2015 LISA GmbH, Bingen, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-translationstring
Version:        1.4
Release:        4.1
Summary:        Utility library for i18n relied on by various Repoze and Pyramid packages
License:        SUSE-Repoze
Group:          Development/Languages/Python
URL:            https://github.com/Pylons/translationstring
Source:         https://files.pythonhosted.org/packages/source/t/translationstring/translationstring-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  git
BuildRequires:  python-rpm-macros
BuildArch:      noarch
# SECTION documentation requirements
BuildRequires:  python3-Sphinx
BuildRequires:  python3-pylons-sphinx-themes
# /SECTION
%python_subpackages

%description
A library used by various Pylons Project packages for internationalization
(i18n) duties related to translation.

This package provides a translation string class, a translation string factory
class, translation and pluralization primitives, and a utility that helps
Chameleon templates use translation facilities of this package. It does not
depend on Babel, but its translation and pluralization services are meant to
work best when provided with an instance of the babel.support.Translations class.

%package     -n %{name}-doc
Summary:        Documentation files for %{name}
Group:          Development/Languages/Python
Provides:       %{python_module translationstring-doc = %{version}}

%description -n %{name}-doc
This package contains documentation files for %{name}.

%prep
%setup -q -n translationstring-%{version}
# drop build date from doc to fix build-compare
sed -i "s/\(html_last_updated_fmt = \).*/\\1None/" docs/conf.py
rm -rf translationstring.egg-info

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

# Need package installed before building docs
pushd docs && PYTHONPATH=%{buildroot}%{python3_sitelib} make html && rm _build/html/.buildinfo
popd

%check
%pytest

%files %{python_files}
%license LICENSE.txt
%doc CONTRIBUTORS.txt COPYRIGHT.txt README.rst
%{python_sitelib}/translationstring
%{python_sitelib}/translationstring-%{version}.dist-info

%files -n %{name}-doc
%doc docs/_build/html

%changelog
* Wed Jun  4 2025 Steve Kowalik <steven.kowalik@suse.com>
- Switch to pyproject macros.
- No more greedy globs in %%files.
* Fri Jun  9 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Wed Jan 13 2021 pgajdos@suse.com
- use %%pytest macro
* Thu Jul 23 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 1.4
  * Drop support for Python 2.6, 3.2 and 3.
  * Update license classifiers
- drop use_pylons_theme.patch
* Thu Feb  1 2018 toddrme2178@gmail.com
- Add use_pylons_theme.patch
  update docs to use pylons-sphinx-themes package instead of git
  submodule update.  Based on:
  * https://github.com/Pylons/translationstring/commit/bb4c396b23dca5ee0ec27c00ed3c49881b5c2245
* Sun Jul  9 2017 aloisio@gmx.com
- Converted to single-spec
- Enabled tests
* Wed Mar  9 2016 bwiedemann@suse.com
- Drop build date from doc to fix build-compare
* Fri Feb  6 2015 hpj@urpla.net
- update to version 1.3:
  - Fix Python 3-specific test failures.
    Restore compatibility with Python 3.2.
- 1.2 (2014-11-04)
  - Add support for message contexts.
  - If the object passed to a TranslationStringFactory __call__ method is
    itself a translation string, use the passed object’s domain instead of the
    domain passed to the factory’s contstructor. See
    https://github.com/Pylons/translationstring/pull/12 .
* Mon Dec 16 2013 cfarrell@suse.com
- license update: SUSE-Repoze
  See spreadsheet linked from license.opensuse.org
* Mon Jul 29 2013 speilicke@suse.com
- Simplify macro usage
- Remove reStructuredText from %%description
* Sun Jul 28 2013 hpj@urpla.net
- version 1.1: initial build
